@@ -1,5 +1,5 @@
 # import DB
-from UNKnownDB.UNDL import Interpreter
+from UNKnownDB.UNDL import Interpreter, APP
 # from UNKnownDB import DB
 
 
@@ -8,8 +8,9 @@ with open('./.Clever.unp/Guide.undl') as code:
 inter = Interpreter.Interpret(lines)
 inter.dictionary()
 form = Interpreter.Form(inter.Form, inter.FormDict)
-print(form.type())
-print(form.Form)
+app = APP.Main()
+app.file_tree('./.Clever.unp')
+app.main_loop()
 
 
 # db = DB.LocalDB("./.Clever.unp")
